package javax.swing.plaf.nimbus;

import java.awt.image.WritableRaster;
import java.util.Arrays;
import java.awt.image.BufferedImage;

class InnerShadowEffect extends ShadowEffect
{
    InnerShadowEffect() {
    }
    
    @Override
    Effect.EffectType getEffectType() {
        return Effect.EffectType.OVER;
    }
    
    @Override
    BufferedImage applyEffect(BufferedImage bufferedImage, BufferedImage bufferedImage2, int w, int height) {
        if (bufferedImage == null || bufferedImage.getType() != 2) {
            throw new IllegalArgumentException("Effect only works with source images of type BufferedImage.TYPE_INT_ARGB.");
        }
        if (bufferedImage2 != null && bufferedImage2.getType() != 2) {
            throw new IllegalArgumentException("Effect only works with destination images of type BufferedImage.TYPE_INT_ARGB.");
        }
        double radians = Math.toRadians((double)(this.angle - 90));
        int n = (int)(Math.sin(radians) * (double)this.distance);
        int n2 = (int)(Math.cos(radians) * (double)this.distance);
        int n3 = n + this.size;
        int n4 = n + this.size;
        int n5 = w + n + this.size + this.size;
        int n6 = height + n + this.size;
        int[] tmpIntArray = Effect.getArrayCache().getTmpIntArray(w);
        byte[] tmpByteArray1 = Effect.getArrayCache().getTmpByteArray1(n5 * n6);
        Arrays.fill(tmpByteArray1, (byte)(-1));
        byte[] tmpByteArray2 = Effect.getArrayCache().getTmpByteArray2(n5 * n6);
        byte[] tmpByteArray3 = Effect.getArrayCache().getTmpByteArray3(n5 * n6);
        WritableRaster raster = bufferedImage.getRaster();
        for (int i = 0; i < height; ++i) {
            int n7 = (i + n4) * n5;
            raster.getDataElements(0, i, w, 1, tmpIntArray);
            for (int j = 0; j < w; ++j) {
                tmpByteArray1[n7 + (j + n3)] = (byte)(255 - ((tmpIntArray[j] & 0xFF000000) >>> 24) & 0xFF);
            }
        }
        float[] gaussianKernel = EffectUtils.createGaussianKernel(this.size * 2);
        EffectUtils.blur(tmpByteArray1, tmpByteArray3, n5, n6, gaussianKernel, this.size * 2);
        EffectUtils.blur(tmpByteArray3, tmpByteArray2, n6, n5, gaussianKernel, this.size * 2);
        float min = Math.min(1.0f / (1.0f - 0.01f * (float)this.spread), 255.0f);
        for (int k = 0; k < tmpByteArray2.length; ++k) {
            int n8 = (int)((float)(tmpByteArray2[k] & 0xFF) * min);
            tmpByteArray2[k] = ((n8 > 255) ? -1 : ((byte)n8));
        }
        if (bufferedImage2 == null) {
            bufferedImage2 = new BufferedImage(w, height, 2);
        }
        WritableRaster raster2 = bufferedImage2.getRaster();
        int red = this.color.getRed();
        int green = this.color.getGreen();
        int blue = this.color.getBlue();
        for (int l = 0; l < height; ++l) {
            int n9 = l + n4;
            int n10 = n9 * n5;
            int n11 = (n9 - n2) * n5;
            for (int n12 = 0; n12 < w; ++n12) {
                int n13 = n12 + n3;
                tmpIntArray[n12] = (((byte)Math.min(255 - (tmpByteArray1[n10 + n13] & 0xFF), tmpByteArray2[n11 + (n13 - n)] & 0xFF) & 0xFF) << 24 | red << 16 | green << 8 | blue);
            }
            raster2.setDataElements(0, l, w, 1, tmpIntArray);
        }
        return bufferedImage2;
    }
}
